package com.muyu.cloud.pay.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.cloud.pay.domain.OrderPayInfo;
import com.muyu.cloud.pay.mapper.OrderPayMapper;
import com.muyu.cloud.pay.service.OrderPayService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Author: DongZeLiang
 * @date: 2024/7/31
 * @Description: 订单支付业务实现层
 * @Version: 1.0
 */
@Service
public class OrderPayServiceImpl extends ServiceImpl<OrderPayMapper, OrderPayInfo> implements OrderPayService {

    /**
     * 根据客户code和分页限制，查询结果
     *
     * @param appCode 客户code
     * @param limit   分页限制
     *
     * @return 支付订单记录
     */
    @Override
    public List<OrderPayInfo> selectOrderPayByAppCodeAndLimit (String appCode, int limit) {
        LambdaQueryWrapper<OrderPayInfo> orderPayInfoQueryWrapper = new LambdaQueryWrapper<>();
        orderPayInfoQueryWrapper.eq(OrderPayInfo::getAppCode, appCode);
        orderPayInfoQueryWrapper.orderBy(true, false, OrderPayInfo::getCreateTime);
        orderPayInfoQueryWrapper.last("limit " + limit);
        return this.list(orderPayInfoQueryWrapper);
    }
}
